@@ -1,18 +1,8 @@
-=head1 NAME
-
-API::Instagram - OO Interface to Instagram REST API
-
-=for HTML <a href="https://travis-ci.org/gabrielmad/API-Instagram"><img src="https://travis-ci.org/gabrielmad/API-Instagram.svg?branch=build%2Fmaster"></a>
-
-=head1 VERSION
-
-version 0.005
-
-=cut
-
 package API::Instagram;
 
-our $VERSION = '0.005';
+# ABSTRACT: OO Interface to Instagram REST API
+
+our $VERSION = '0.006';
 
 use Moo;
 
@@ -23,6 +13,7 @@ use warnings;
 use URI;
 use JSON;
 use LWP::UserAgent;
+use LWP::Protocol::https;
 # use LWP::Protocol::Net::Curl;
 
 use API::Instagram::User;
@@ -31,11 +22,6 @@ use API::Instagram::Tag;
 use API::Instagram::Media;
 use API::Instagram::Media::Comment;
 
-
-# https://instagram.com/api/v1/direct_share/pending/
-# https://instagram.com/api/v1/direct_share/inbox/
-
-
 has client_id         => ( is => 'ro', required => 1 );
 has client_secret     => ( is => 'ro', required => 1 );
 has redirect_uri      => ( is => 'ro', required => 1 );
@@ -52,110 +38,6 @@ has _endpoint_url     => ( is => 'ro', default => sub { 'https://api.instagram.c
 has _authorize_url    => ( is => 'ro', default => sub { 'https://api.instagram.com/oauth/authorize'    } );
 has _access_token_url => ( is => 'ro', default => sub { 'https://api.instagram.com/oauth/access_token' } );
 
-
-=head1 SYNOPSIS
-
-	use API::Instagram;
-
-	my $instagram = API::Instagram->new({
-			client_id   	=> $client_id,
-			client_secret	=> $client_secret,
-			redirect_uri	=> 'http://localhost',
-	});
-
-	# Authenticated user feed
-	my $my_user = $instagram->user;
-	my $feed    = $my_user->feed( count => 5 );
-
-	for my $media ( @$feed ) {
-
-		printf "Caption: %s\n", $media->caption;
-		printf "Posted by %s at %s (%d likes)\n\n", $media->user->username, $media->created_time, $media->likes;
-
-	}
-
-
-=head1 DESCRIPTION
-
-This module implements an OO interface to Instagram REST API.
-
-
-=head2 Authentication
-
-Instagram API uses the OAuth2 for authentication, requering a C<client_id> and
-C<client_secret>. See L<http://instagr.am/developer/register/> for details.
-
-=head3 Authorize
-
-Get the AUTH URL to authenticate.
-
-	use API::Instagram;
-
-	my $instagram = API::Instagram->new({
-			client_id		=> 'xxxxxxxxxx',
-			client_secret	=> 'xxxxxxxxxx',
-			redirect_uri	=> 'http://localhost',
-			scope           => 'basic',
-			response_type   => 'code',
-			granty_type     => 'authorization_code',
-	});
-
-	print $instagram->get_auth_url;
-
-
-=head3 Authenticate
-
-After authorization, Instagram will redirected the user to the URL in
-C<redirect_uri> with a code as an URL query parameter. This code is needed
-to obtain an acess token.
-
-	$instagram->set_code( $code );
-	my $access_token = $instagram->get_access_token;
-
-=head3 Request
-
-With the access token its possible to do Instagram API requests using the
-authenticated user credentials.
-
-	$instagram->access_token( $access_token );
-	my $me = $instagram->get_user;
-	print $me->full_name;
-
-
-=head1 METHODS
-
-=head2 new
-
-	my $instagram = API::Instagram->new({
-			client_id   	=> $client_id,
-			client_secret	=> $client_secret,
-			redirect_uri	=> 'http://localhost',
-			scope           => 'basic',
-			response_type   => 'code',
-			granty_type     => 'authorization_code',
-			no_cache        => 1,
-	});
-
-Returns an L<API::Instagram> object.
-
-Set C<client_id>, C<client_secret> and C<redirect_uri> with the ones registered
-to your application. See L<http://instagram.com/developer/clients/manage/>.
-
-C<scope> is the scope of access. See L<http://instagram.com/developer/authentication/#scope>.
-
-C<response_type> and C<granty_type> do no vary. See L<http://instagram.com/developer/authentication/>.
-
-By default, L<API::Instagram> caches created objects to avoid duplications. You can disable
-this feature setting a true value to C<no_chace> parameter.
-
-=head2 get_auth_url
-
-	my $auth_url = $instagram->get_auth_url;
-	print $auth_url;
-
-Returns an Instagram authorization URL.
-
-=cut
 sub get_auth_url { 
 	my $self = shift;
 
@@ -172,19 +54,6 @@ sub get_auth_url {
 }
 
 
-=head2 get_access_token
-
-	my $access_token = $instagram->get_access_token;
-
-	or
-
-	my ( $access_token, $auth_user ) = $instagram->get_access_token;
-
-Returns the access token string if the context is looking for a scalar, or an
-array containing the access token string and the authenticated user
-L<API::Instagram::User> object if looking for a list value.
-
-=cut
 sub get_access_token {
 	my $self = shift;
 
@@ -194,7 +63,7 @@ sub get_access_token {
 	}
 
 	my $data = { map { $_ => $self->$_ } @access_token_fields };
-	my $json = from_json $self->_ua  ->post( $self->_access_token_url, $data )->content;
+	my $json = from_json $self->_ua->post( $self->_access_token_url, $data )->content;
 
 	my $meta = $json->{meta};
 	confess "ERROR $meta->{error_type}: $meta->{error_message}" if $meta->{code} ne '200';
@@ -203,54 +72,17 @@ sub get_access_token {
 }
 
 
-=head2 media
-
-	my $media = $instagram->media( $media_id );
-	say $media->type;
-
-Get information about a media object. Returns an L<API::Instagram::Media> object.
-
-=cut
 sub media { shift->_get_obj( 'media', '/medias', 'medias', 'id', shift ) }
 
 
-=head2 user
-
-	my $me = $instagram->user; # Authenticated user
-	say $me->username;
-
-	my $user = $instagram->user( $user_id );
-	say $user->full_name;
-
-Get information about an user. Returns an L<API::Instagram::User> object.
-
-=cut
 sub user { shift->_get_obj( 'user', '/users', 'users', 'id', shift || 'self' ) }
 
 
-=head2 location
-
-	my $location = $instagram->location( $location_id );
-	say $location->name;
-
-Get information about a location. Returns an L<API::Instagram::Location> object.
-
-=cut
 sub location { shift->_get_obj( 'location', '/locations', 'locations', 'id', shift ) }
 
 
-=head2 tag
-
-	my $tag = $instagram->tag('perl');
-	say $tag->media_count;
-
-Get information about a tag. Returns an L<API::Instagram::Tag> object.
-
-=cut
 sub tag { shift->_get_obj( 'tag', '/tags', 'tags', 'name', shift ) }
 
-
-
 sub _get_obj {
 	my ( $self, $obj, $url, $cache, $key, $data, $opts ) = @_;
 
@@ -258,9 +90,10 @@ sub _get_obj {
 	return if ref $id || !$id;
 
 	my $method = "_create_${obj}_object";
-	$data      = ref $data eq 'HASH' ? $data : $self->_request( "$url/$id" )->{data};
 
-	my $return = $self->_cache($cache)->{$id} //= $self->$method( $data );
+	my $return = $self->_cache($cache)->{$id} //= $self->$method(
+					ref $data eq 'HASH' ? $data : $self->_request( "$url/$id" )->{data}
+				);
 
 	delete $self->_cache($cache)->{$id} if $self->no_cache;
 
@@ -345,16 +178,30 @@ sub _request {
 		my $uri = URI->new( $self->_endpoint_url );
 		$uri->path_segments( $uri->path_segments, split '/', $url );
 		$uri->query_form($params);
-	    $url = $uri->as_string;
+		$url = $uri->as_string;
 	}
 
-	my $res  = decode_json $self->_ua  ->get( $url )->decoded_content;
+	my $res  = decode_json $self->_ua->get( $url )->decoded_content;
 	my $meta = $res->{meta};
 	carp "ERROR $meta->{error_type}: $meta->{error_message}" if $meta->{code} ne '200';
 
 	$res;
 }
 
+sub _simple_request {
+	my $self   = shift;
+	my $url    = shift;
+	my $params = shift;
+
+	confess "A valid access_token is required" unless defined $self->access_token;
+	$params->{access_token} = $self->access_token;
+
+	my $uri = URI->new( $url );
+	$uri->query_form($params);
+
+	decode_json $self->_ua->get( $uri->as_string )->decoded_content;
+}
+
 sub _cache {
 	my ( $self, $cache ) = @_;
 	$self->_obj_cache->{$cache};
@@ -365,32 +212,177 @@ sub _delete_cache {
 	delete $self->_obj_cache->{$cache}->{$id};
 }
 
+
 1;
 
-=head1 BUGS
+__END__
 
-Please report me bugs if you find any.
+=pod
 
-L<http://github.com/gabrielmad/API-Instagram/issues>
+=encoding UTF-8
 
+=head1 NAME
 
-=head1 SEE ALSO
+API::Instagram - OO Interface to Instagram REST API
 
-=over
+=for Pod::Coverage client_id client_secret grant_type no_cache redirect_uri response_type scope
 
-=item *
+=for HTML <a href="https://travis-ci.org/gabrielmad/API-Instagram"><img src="https://travis-ci.org/gabrielmad/API-Instagram.svg?branch=build%2Fmaster"></a>
 
-L<WebService::Instagram>
+=head1 VERSION
 
-=back
+version 0.006
+
+=head1 SYNOPSIS
+
+	use API::Instagram;
+
+	my $instagram = API::Instagram->new({
+			client_id   	=> $client_id,
+			client_secret	=> $client_secret,
+			redirect_uri	=> 'http://localhost',
+	});
+
+	# Authenticated user feed
+	my $my_user = $instagram->user;
+	my $feed    = $my_user->feed( count => 5 );
+
+	for my $media ( @$feed ) {
+
+		printf "Caption: %s\n", $media->caption;
+		printf "Posted by %s at %s (%d likes)\n\n", $media->user->username, $media->created_time, $media->likes;
+
+	}
+
+=head1 DESCRIPTION
+
+This module implements an OO interface to Instagram REST API.
+
+=head2 Authentication
+
+Instagram API uses the OAuth2 for authentication, requering a C<client_id> and
+C<client_secret>. See L<http://instagr.am/developer/register/> for details.
+
+=head3 Authorize
+
+Get the AUTH URL to authenticate.
+
+	use API::Instagram;
+
+	my $instagram = API::Instagram->new({
+			client_id		=> 'xxxxxxxxxx',
+			client_secret	=> 'xxxxxxxxxx',
+			redirect_uri	=> 'http://localhost',
+			scope           => 'basic',
+			response_type   => 'code',
+			granty_type     => 'authorization_code',
+	});
+
+	print $instagram->get_auth_url;
+
+=head3 Authenticate
+
+After authorization, Instagram will redirected the user to the URL in
+C<redirect_uri> with a code as an URL query parameter. This code is needed
+to obtain an acess token.
+
+	$instagram->code( $code );
+	my $access_token = $instagram->get_access_token;
+
+=head3 Request
+
+With the access token its possible to do Instagram API requests using the
+authenticated user credentials.
+
+	$instagram->access_token( $access_token );
+	my $me = $instagram->user;
+	print $me->full_name;
+
+=head1 METHODS
+
+=head2 new
+
+	my $instagram = API::Instagram->new({
+			client_id   	=> $client_id,
+			client_secret	=> $client_secret,
+			redirect_uri	=> 'http://localhost',
+			scope           => 'basic',
+			response_type   => 'code',
+			granty_type     => 'authorization_code',
+			no_cache        => 1,
+	});
+
+Returns an L<API::Instagram> object.
+
+Set C<client_id>, C<client_secret> and C<redirect_uri> with the ones registered
+to your application. See L<http://instagram.com/developer/clients/manage/>.
+
+C<scope> is the scope of access. See L<http://instagram.com/developer/authentication/#scope>.
+
+C<response_type> and C<granty_type> do no vary. See L<http://instagram.com/developer/authentication/>.
+
+By default, L<API::Instagram> caches created objects to avoid duplications. You can disable
+this feature setting a true value to C<no_chace> parameter.
+
+=head2 get_auth_url
+
+	my $auth_url = $instagram->get_auth_url;
+	print $auth_url;
+
+Returns an Instagram authorization URL.
+
+=head2 get_access_token
+
+	my $access_token = $instagram->get_access_token;
+
+	or
+
+	my ( $access_token, $auth_user ) = $instagram->get_access_token;
+
+Returns the access token string if the context is looking for a scalar, or an
+array containing the access token string and the authenticated user
+L<API::Instagram::User> object if looking for a list value.
+
+=head2 media
+
+	my $media = $instagram->media( $media_id );
+	say $media->type;
+
+Get information about a media object. Returns an L<API::Instagram::Media> object.
+
+=head2 user
+
+	my $me = $instagram->user; # Authenticated user
+	say $me->username;
+
+	my $user = $instagram->user( $user_id );
+	say $user->full_name;
+
+Get information about an user. Returns an L<API::Instagram::User> object.
+
+=head2 location
+
+	my $location = $instagram->location( $location_id );
+	say $location->name;
+
+Get information about a location. Returns an L<API::Instagram::Location> object.
+
+=head2 tag
+
+	my $tag = $instagram->tag('perl');
+	say $tag->media_count;
+
+Get information about a tag. Returns an L<API::Instagram::Tag> object.
 
 =head1 AUTHOR
 
-Gabriel Vieira C<< <gabriel.vieira at gmail.com> >>
+Gabriel Vieira <gabriel.vieira@gmail.com>
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, Gabriel Vieira C<< <gabriel.vieira at gmail.com> >>. All rights reserved.
+This software is copyright (c) 2014 by Gabriel Vieira.
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
