@@ -1,11 +1,7 @@
-=head1 NAME
-
-API::Instagram::Media - Instagram Media Object
-
-=cut
-
 package API::Instagram::Media;
 
+# ABSTRACT: Instagram Media Object
+
 use Moo;
 use Time::Moment;
 
@@ -15,7 +11,7 @@ has type           => ( is => 'ro' );
 has user           => ( is => 'ro' );
 has link           => ( is => 'ro' );
 has filter         => ( is => 'ro' );
-has tags           => ( is => 'ro' );
+has tags           => ( is => 'ro', lazy => 1, builder => 1 );
 has location       => ( is => 'ro' );
 has images         => ( is => 'ro' );
 has videos         => ( is => 'ro' );
@@ -30,7 +26,6 @@ sub BUILD {
 	my $instagram           = $self->_instagram;
 	$self->{user}           = $instagram->user( $self->{user} );
 	$self->{location}       = $instagram->location( $self->{location} );
-	$self->{tags}           = [ map { $instagram->tag($_) } @{$self->{tags}} ];
 	$self->{users_in_photo} = [
 		map {
 			{
@@ -41,6 +36,47 @@ sub BUILD {
 	];
 }
 
+sub _build_tags {
+	my $self = shift;
+	[ map { $self->_instagram->tag($_) } @{$self->{tags}} ]
+}
+
+sub get_likes {
+	my $self = shift;
+	my %opts = @_;
+	my $url  = "/media/" . $self->id . "/likes";
+	my $instagram = $self->_instagram;
+	[ map { $instagram->user($_) } $instagram->_get_list( %opts, url => $url ) ]
+}
+
+
+sub get_comments {
+	my $self = shift;
+	my %opts = @_;
+	my $url  = "/media/" . $self->id . "/comments";
+	my $instagram = $self->_instagram;
+	[ map { $instagram->_create_comment_object($_) } $instagram->_get_list( %opts, url => $url ) ]
+}
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+API::Instagram::Media - Instagram Media Object
+
+=for Pod::Coverage BUILD
+
+=head1 VERSION
+
+version 0.006
+
 =head1 SYNOPSIS
 
 	my $media = $instagram->media(3);
@@ -51,7 +87,6 @@ sub BUILD {
 	my $location = $media->location;
 	printf "Media Location: %s (%f,%f)", $location->name, $location->latitude, $location->longitude;
 
-
 =head1 DESCRIPTION
 
 See L<http://instagr.am/developer/endpoints/media/>.
@@ -139,15 +174,6 @@ Returns a list of L<API::Instagram::User> objects of users who liked the media.
 
 Accepts C<count>.
 
-=cut
-sub get_likes {
-	my $self = shift;
-	my %opts = @_;
-	my $url  = "/media/" . $self->id . "/likes";
-	my $instagram = $self->_instagram;
-	[ map { $instagram->user($_) } $instagram->_get_list( %opts, url => $url ) ]
-}
-
 =head2 get_comments
 
 	my @comments = $media->get_comments( count => 5 );
@@ -156,14 +182,15 @@ Returns a list of L<API::Instagram::Media::Comment> objects of the media.
 
 Accepts C<count>.
 
+=head1 AUTHOR
+
+Gabriel Vieira <gabriel.vieira@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Gabriel Vieira.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-sub get_comments {
-	my $self = shift;
-	my %opts = @_;
-	my $url  = "/media/" . $self->id . "/comments";
-	my $instagram = $self->_instagram;
-	[ map { $instagram->_create_comment_object($_) } $instagram->_get_list( %opts, url => $url ) ]
-}
-
-1;
\ No newline at end of file
